@@ -12,15 +12,21 @@
 #include "networks/MultilayerNetwork.hpp"
 #include "r_functions.h"
 
+std::vector<const uu::net::Network*>
+resolve_const_layers(
+    const uu::net::MultilayerNetwork* mnet,
+    const Rcpp::CharacterVector& names
+);
+
 std::vector<uu::net::Network*>
 resolve_layers(
-    const uu::net::MultilayerNetwork* mnet,
+    uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::unordered_set<uu::net::Network*>
 resolve_layers_unordered(
-    const uu::net::MultilayerNetwork* mnet,
+    uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
@@ -42,18 +48,30 @@ resolve_actors_unordered(
     const Rcpp::CharacterVector& names
 );
 
-std::vector<std::pair<const uu::net::Vertex*, uu::net::Network*>>
-        resolve_vertices(
+std::vector<std::pair<const uu::net::Vertex*, const uu::net::Network*>>
+        resolve_const_vertices(
             const uu::net::MultilayerNetwork* mnet,
             const Rcpp::DataFrame& vertex_matrix
         );
 
-std::vector<std::tuple<const uu::net::Vertex*, uu::net::Network*, const uu::net::Vertex*, uu::net::Network*>>
-        resolve_edges(
+std::vector<std::pair<const uu::net::Vertex*, uu::net::Network*>>
+resolve_vertices(
+    uu::net::MultilayerNetwork* mnet,
+    const Rcpp::DataFrame& vertex_matrix
+);
+
+std::vector<std::tuple<const uu::net::Vertex*, const uu::net::Network*, const uu::net::Vertex*, const uu::net::Network*>>
+        resolve_const_edges(
             const uu::net::MultilayerNetwork* mnet,
             const Rcpp::DataFrame& edge_matrix
         );
 
+std::vector<std::tuple<const uu::net::Vertex*, uu::net::Network*, const uu::net::Vertex*,  uu::net::Network*>>
+resolve_edges(
+    uu::net::MultilayerNetwork* mnet,
+    const Rcpp::DataFrame& edge_matrix
+);
+
 
 uu::net::EdgeMode
 resolve_mode(
