@@ -14,9 +14,9 @@ class GMetaNetwork
   public:
 
     std::unique_ptr<MultiNetwork> w;
-    std::unordered_map<const Edge*, size_t> edge_type;
+    std::unordered_map<const Edge*, std::size_t> edge_type;
     std::unordered_map<const Edge*, double> edge_weight;
-    size_t order = 0;
+    std::size_t order = 0;
     std::unordered_map<const Vertex*, std::set<const Vertex*>> mapping;
     std::unordered_map<const Vertex*, const Vertex*> reverse_mapping;
 
@@ -41,7 +41,7 @@ class GMetaNetwork
     edge(
         const Vertex* u,
         const Vertex* v,
-        size_t type,
+        std::size_t type,
         double weight = 1.0
     );
 
@@ -50,7 +50,7 @@ class GMetaNetwork
         const Edge*
     ) const;
 
-    size_t
+    std::size_t
     get_type(
         const Edge*
     ) const;
