@@ -33,14 +33,14 @@ convert(
 std::unique_ptr<MetaNetwork>
 aggregate(
     const Network* g,
-    std::unordered_map<const Vertex*, size_t> community
+    std::unordered_map<const Vertex*, std::size_t> community
 );
 
 
 void
 expand(
     const std::vector<std::unique_ptr<MetaNetwork>>& levels,
-    size_t i,
+    std::size_t i,
     const Vertex* v,
     Community<Network>* com
 );
