@@ -13,9 +13,9 @@ bottom_up_search(
      const std::vector<freq_itemset>& atoms,
      std::vector<freq_itemset>& freq,
      std::vector<freq_itemset>& closed,
-     std::map<std::vector<size_t>, std::vector<freq_itemset>>& freq_supersets,
-     size_t min_sup,
-     size_t min_size
+     std::map<std::vector<std::size_t>, std::vector<freq_itemset>>& freq_supersets,
+     std::size_t min_sup,
+     std::size_t min_size
      );
 
 }
