@@ -2,14 +2,15 @@
 #define UU_CORE_ARULES_JOINITEMS_H_
 
 #include <vector>
+#include <cstddef>
 
 namespace uu {
 namespace core {
 
-std::vector<size_t>
+std::vector<std::size_t>
 join_items(
-           std::vector<size_t> items1,
-           std::vector<size_t> items2
+           std::vector<std::size_t> items1,
+           std::vector<std::size_t> items2
            );
 
 }
