@@ -16,5 +16,5 @@ DuplicateElementException::what() const throw()
     return value.data();
 }
 
-} // namespace core
-} // namespace uu
+}
+} 
