@@ -44,19 +44,19 @@ class SortedRandomBag
     std::shared_ptr<SortedRandomBagEntry<ELEMENT_TYPE>> header;
 
     /* Number of entries for which the sorted set is optimized. */
-    size_t capacity = 1;
+    std::size_t capacity = 1;
 
     /* Current number of entries, that is, distinct objects. */
-    size_t num_entries = 0;
+    std::size_t num_entries = 0;
 
     /* Current number of objects. */
-    size_t num_objects = 0;
+    std::size_t num_objects = 0;
 
     /* Maximum level */
-    size_t MAX_LEVEL = 0;
+    std::size_t MAX_LEVEL = 0;
 
     /* Current maximum level in use. */
-    size_t level;
+    std::size_t level;
 
   public:
 
@@ -76,7 +76,7 @@ class SortedRandomBag
      * @param start_capacity the initial capacity for which the sorted set is optimized
      */
     SortedRandomBag(
-        size_t start_capacity
+        std::size_t start_capacity
     );
 
     /** Iterator over the objects in this collection. */
@@ -142,12 +142,12 @@ class SortedRandomBag
     ) const;
 
     /** Returns the number of objects in the collection */
-    size_t
+    std::size_t
     size(
     ) const;
 
     /** Returns the number of distinct objects in the collection */
-    size_t
+    std::size_t
     dsize(
     ) const;
 
@@ -178,7 +178,7 @@ class SortedRandomBag
      */
     const ELEMENT_TYPE&
     at(
-        size_t
+        std::size_t
     ) const;
 
     /** Returns a random object, uniform probability */
@@ -251,7 +251,7 @@ SortedRandomBag<ELEMENT_TYPE>::
     {
         tmp.push_back(next);
 
-        for (size_t i=0; i<current->forward.size(); i++)
+        for (std::size_t i=0; i<current->forward.size(); i++)
         {
             current->forward[i] = nullptr;
         }
@@ -265,7 +265,7 @@ SortedRandomBag<ELEMENT_TYPE>::
 template <class ELEMENT_TYPE>
 SortedRandomBag<ELEMENT_TYPE>::
 SortedRandomBag(
-    size_t start_capacity
+    std::size_t start_capacity
 )
 {
     capacity = start_capacity;
@@ -354,7 +354,7 @@ operator!=(
 }
 
 template <class ELEMENT_TYPE>
-size_t
+std::size_t
 SortedRandomBag<ELEMENT_TYPE>::size(
 ) const
 {
@@ -362,7 +362,7 @@ SortedRandomBag<ELEMENT_TYPE>::size(
 }
 
 template <class ELEMENT_TYPE>
-size_t
+std::size_t
 SortedRandomBag<ELEMENT_TYPE>::dsize(
 ) const
 {
@@ -433,7 +433,7 @@ template <class ELEMENT_TYPE>
 const ELEMENT_TYPE&
 SortedRandomBag<ELEMENT_TYPE>::
 at(
-    size_t pos
+    std::size_t pos
 ) const
 {
     if (pos < 0 || pos >= num_entries)
@@ -442,7 +442,7 @@ at(
     }
 
     std::shared_ptr<const SortedRandomBagEntry<ELEMENT_TYPE>> x = header;
-    size_t so_far=0;
+    std::size_t so_far=0;
 
     for (int i = level; i >= 0; i--)
     {
@@ -478,8 +478,8 @@ add(
     std::shared_ptr<SortedRandomBagEntry<ELEMENT_TYPE>> x = header;
     std::vector<std::shared_ptr<SortedRandomBagEntry<ELEMENT_TYPE>> > update;
     update.resize(level+1);
-    std::vector<size_t> skipped_positions_per_level;
-    size_t skipped_positions = 0;
+    std::vector<std::size_t> skipped_positions_per_level;
+    std::size_t skipped_positions = 0;
     skipped_positions_per_level.resize(level+1,0);
 
     for (int i = level; i >= 0; i--)
@@ -511,14 +511,14 @@ add(
             header->increment(num_entries);
         }
 
-        size_t lvl = random_level(MAX_LEVEL,P);
+        std::size_t lvl = random_level(MAX_LEVEL,P);
 
         if (lvl > level)
         {
             update.resize(lvl+1);
             skipped_positions_per_level.resize(lvl+1,0);
 
-            for (size_t i = level + 1; i <= lvl; i++)
+            for (std::size_t i = level + 1; i <= lvl; i++)
             {
                 update[i] = header;
                 update[i]->link_length[i] = num_entries;
@@ -529,9 +529,9 @@ add(
 
         x = std::make_shared<SortedRandomBagEntry<ELEMENT_TYPE> >(lvl, value);
 
-        for (size_t i = 0; i <= lvl; i++)
+        for (std::size_t i = 0; i <= lvl; i++)
         {
-            size_t offset = skipped_positions-skipped_positions_per_level[i];
+            std::size_t offset = skipped_positions-skipped_positions_per_level[i];
 
             x->forward[i] = update[i]->forward[i];
 
@@ -549,7 +549,7 @@ add(
             update[i]->link_length[i] = offset+1;
         }
 
-        for (size_t i = lvl+1; i <= level; i++)
+        for (std::size_t i = lvl+1; i <= level; i++)
         {
             update[i]->link_length[i]++;
         }
@@ -578,8 +578,8 @@ add(
     std::shared_ptr<SortedRandomBagEntry<ELEMENT_TYPE>> x = header;
     std::vector<std::shared_ptr<SortedRandomBagEntry<ELEMENT_TYPE>> > update;
     update.resize(level+1);
-    std::vector<size_t> skipped_positions_per_level;
-    size_t skipped_positions = 0;
+    std::vector<std::size_t> skipped_positions_per_level;
+    std::size_t skipped_positions = 0;
     skipped_positions_per_level.resize(level+1,0);
 
     for (int i = level; i >= 0; i--)
@@ -612,14 +612,14 @@ add(
             header->increment(num_entries);
         }
 
-        size_t lvl = random_level(MAX_LEVEL,P);
+        std::size_t lvl = random_level(MAX_LEVEL,P);
 
         if (lvl > level)
         {
             update.resize(lvl+1);
             skipped_positions_per_level.resize(lvl+1,0);
 
-            for (size_t i = level + 1; i <= lvl; i++)
+            for (std::size_t i = level + 1; i <= lvl; i++)
             {
                 update[i] = header;
                 update[i]->link_length[i] = num_entries;
@@ -630,9 +630,9 @@ add(
 
         x = std::make_shared<SortedRandomBagEntry<ELEMENT_TYPE> >(lvl, std::move(value));
 
-        for (size_t i = 0; i <= lvl; i++)
+        for (std::size_t i = 0; i <= lvl; i++)
         {
-            size_t offset = skipped_positions-skipped_positions_per_level[i];
+            std::size_t offset = skipped_positions-skipped_positions_per_level[i];
 
             x->forward[i] = update[i]->forward[i];
 
@@ -650,7 +650,7 @@ add(
             update[i]->link_length[i] = offset+1;
         }
 
-        for (size_t i = lvl+1; i <= level; i++)
+        for (std::size_t i = lvl+1; i <= level; i++)
         {
             update[i]->link_length[i]++;
         }
@@ -712,7 +712,7 @@ erase(
         }
 
         // otherwise delete the entry
-        for (size_t i = 0; i <= level; i++)
+        for (std::size_t i = 0; i <= level; i++)
         {
             if (update[i]->forward[i] != x)
             {
