@@ -14,15 +14,15 @@ template <typename E>
 void
 move(
     std::vector<E>& vec,
-    size_t from,
-    size_t to
+    std::size_t from,
+    std::size_t to
 );
 
 
-std::vector<size_t>
+std::vector<std::size_t>
 seq(
-    size_t from,
-    size_t to
+    std::size_t from,
+    std::size_t to
 );
 
 }
