@@ -6,10 +6,10 @@ namespace uu {
 namespace net {
 
 
-std::vector<size_t>
+std::vector<std::size_t>
 create_eq_seeds(
-    size_t num_actors,
-    size_t num_communities
+    std::size_t num_actors,
+    std::size_t num_communities
 )
 {
     if (num_actors % num_communities != 0)
@@ -17,10 +17,10 @@ create_eq_seeds(
         throw core::WrongParameterException("the number of actors must be a multiple of the number of communities");
     }
 
-    std::vector<size_t> seeds;
+    std::vector<std::size_t> seeds;
     seeds.push_back(0);
 
-    for (size_t i=1; i<=num_communities; i++)
+    for (std::size_t i=1; i<=num_communities; i++)
     {
         seeds.push_back(seeds.at(i-1) + num_actors/num_communities);
     }
@@ -31,9 +31,9 @@ create_eq_seeds(
 
 std::pair<std::unique_ptr<MultilayerNetwork>, std::unique_ptr<CommunityStructure<MultilayerNetwork>>>
 generate_pep(
-    size_t num_layers,
-    size_t num_actors,
-    size_t num_communities,
+    std::size_t num_layers,
+    std::size_t num_actors,
+    std::size_t num_communities,
     const std::vector<double>& p_internal,
     const std::vector<double>& p_external
 )
@@ -44,10 +44,10 @@ generate_pep(
 
 std::pair<std::unique_ptr<MultilayerNetwork>, std::unique_ptr<CommunityStructure<MultilayerNetwork>>>
 generate_peo(
-    size_t num_layers,
-    size_t num_actors,
-    size_t num_communities,
-    size_t overlapping_size,
+    std::size_t num_layers,
+    std::size_t num_actors,
+    std::size_t num_communities,
+    std::size_t overlapping_size,
     const std::vector<double>& p_internal,
     const std::vector<double>& p_external
 )
@@ -56,17 +56,17 @@ generate_peo(
 
     // define communities
     auto com = std::make_unique<CommunityStructure<MultilayerNetwork>>();
-    std::vector<size_t> seeds = create_eq_seeds(num_actors, num_communities);
+    std::vector<std::size_t> seeds = create_eq_seeds(num_actors, num_communities);
 
-    for (size_t i=0; i<seeds.size()-1; i++)
+    for (std::size_t i=0; i<seeds.size()-1; i++)
     {
         auto c = std::make_unique<Community<MultilayerNetwork>>();
 
-        for (size_t l=0; l<num_layers; l++)
+        for (std::size_t l=0; l<num_layers; l++)
         {
             auto layer = net->layers()->at(l);
 
-            for (size_t a = seeds[i]; a < seeds[i+1]+overlapping_size && a < net->actors()->size(); a++)
+            for (std::size_t a = seeds[i]; a < seeds[i+1]+overlapping_size && a < net->actors()->size(); a++)
             {
                 auto actor = net->actors()->at(a);
                 c->add(MLVertex(actor, layer));
@@ -85,9 +85,9 @@ generate_peo(
 
 std::pair<std::unique_ptr<MultilayerNetwork>, std::unique_ptr<CommunityStructure<MultilayerNetwork>>>
 generate_sep(
-    size_t num_layers,
-    size_t num_actors,
-    size_t num_communities,
+    std::size_t num_layers,
+    std::size_t num_actors,
+    std::size_t num_communities,
     const std::vector<double>& p_internal,
     const std::vector<double>& p_external
 )
@@ -98,10 +98,10 @@ generate_sep(
 
 std::pair<std::unique_ptr<MultilayerNetwork>, std::unique_ptr<CommunityStructure<MultilayerNetwork>>>
 generate_seo(
-    size_t num_layers,
-    size_t num_actors,
-    size_t num_communities,
-    size_t overlapping_size,
+    std::size_t num_layers,
+    std::size_t num_actors,
+    std::size_t num_communities,
+    std::size_t overlapping_size,
     const std::vector<double>& p_internal,
     const std::vector<double>& p_external
 )
@@ -115,17 +115,17 @@ generate_seo(
 
     // define communities
     auto com = std::make_unique<CommunityStructure<MultilayerNetwork>>();
-    std::vector<size_t> seeds = create_eq_seeds(num_actors, num_communities/2);
+    std::vector<std::size_t> seeds = create_eq_seeds(num_actors, num_communities/2);
 
-    for (size_t i=0; i<seeds.size()-1; i++)
+    for (std::size_t i=0; i<seeds.size()-1; i++)
     {
         auto c = std::make_unique<Community<MultilayerNetwork>>();
 
-        for (size_t l=0; l<num_layers-1; l++)
+        for (std::size_t l=0; l<num_layers-1; l++)
         {
             auto layer = net->layers()->at(l);
 
-            for (size_t a = seeds[i]; a < seeds[i+1]+overlapping_size && a < net->actors()->size(); a++)
+            for (std::size_t a = seeds[i]; a < seeds[i+1]+overlapping_size && a < net->actors()->size(); a++)
             {
                 auto actor = net->actors()->at(a);
                 c->add(MLVertex(actor, layer));
@@ -138,11 +138,11 @@ generate_seo(
     //create communities on the last layer
     auto layer = net->layers()->at(num_layers-1);
 
-    for (size_t s=0; s<num_communities/2; s++)
+    for (std::size_t s=0; s<num_communities/2; s++)
     {
         auto c = std::make_unique<Community<MultilayerNetwork>>();
 
-        for (size_t a = s; a < net->actors()->size(); a += (num_actors/num_communities*2))
+        for (std::size_t a = s; a < net->actors()->size(); a += (num_actors/num_communities*2))
         {
             auto actor = net->actors()->at(a);
             c->add(MLVertex(actor, layer));
