@@ -2,7 +2,7 @@
 
 #include "core/exceptions/assert_not_null.hpp"
 #include "core/exceptions/WrongParameterException.hpp"
-#include "core/utils/names.hpp"
+#include "core/utils/NameIterator.hpp"
 #include "operations/_impl/add_predefined_subgraphs.hpp"
 #include "objects/Vertex.hpp"
 
@@ -12,9 +12,9 @@ namespace net {
 
 std::unique_ptr<Network>
 null_graph(
-    size_t n,
+    std::size_t n,
     EdgeDir dir,
-    bool allows_loops
+    LoopMode allows_loops
 )
 {
     std::string name = "N_" + std::to_string(n);
@@ -26,9 +26,9 @@ null_graph(
 
 std::unique_ptr<MultilayerNetwork>
 null_multiplex(
-    size_t n,
+    std::size_t n,
     const std::vector<EdgeDir>& dir,
-    const std::vector<bool>& allows_loops
+    const std::vector<LoopMode>& allows_loops
 )
 {
     std::string name = "N_" + std::to_string(n) + "_" + std::to_string(dir.size());
@@ -42,11 +42,11 @@ null_multiplex(
 
     // Adding layers
     core::NameIterator layer_names("l", dir.size());
-    size_t l = 0;
+    std::size_t l = 0;
 
     for (auto layer_name: layer_names)
     {
-        g->layers()->add(std::make_unique<Network>(layer_name, dir[l], allows_loops[l]));
+        g->layers()->add(layer_name, dir[l], allows_loops[l]);
         l++;
     }
 
@@ -72,12 +72,12 @@ null_multiplex(
 
 std::unique_ptr<MultilayerNetwork>
 null_multiplex(
-    size_t n,
-    size_t l
+    std::size_t n,
+    std::size_t l
 )
 {
     std::vector<uu::net::EdgeDir> dir(l, uu::net::EdgeDir::UNDIRECTED);
-    std::vector<bool> loops(l, true);
+    std::vector<LoopMode> loops(l, LoopMode::ALLOWED);
     return null_multiplex(n, dir, loops);
 }
 
@@ -86,12 +86,12 @@ null_multiplex(
 
 std::unique_ptr<Network>
 complete_graph(
-    size_t n,
+    std::size_t n,
     EdgeDir dir
 )
 {
     std::string name = "K_" + std::to_string(n);
-    bool allows_loops = false;
+    LoopMode allows_loops = LoopMode::DISALLOWED;
     auto g = std::make_unique<Network>(name, dir, allows_loops);
     add_complete_subgraph(g.get(), n);
     return g;
@@ -100,13 +100,13 @@ complete_graph(
 
 std::unique_ptr<Network>
 complete_bipartite_graph(
-    size_t n1,
-    size_t n2,
+    std::size_t n1,
+    std::size_t n2,
     EdgeDir dir
 )
 {
     std::string name = "K_" + std::to_string(n1) + "_" + std::to_string(n2);
-    bool allows_loops = false;
+    LoopMode allows_loops = LoopMode::DISALLOWED;
     auto g = std::make_unique<Network>(name, dir, allows_loops);
     add_complete_bipartite_subgraph(g.get(), n1, n2);
     return g;
@@ -115,12 +115,12 @@ complete_bipartite_graph(
 
 std::unique_ptr<Network>
 path_graph(
-    size_t n,
+    std::size_t n,
     EdgeDir dir
 )
 {
     std::string name = "P_" + std::to_string(n);
-    bool allows_loops = false;
+    LoopMode allows_loops = LoopMode::DISALLOWED;
     auto g = std::make_unique<Network>(name, dir, allows_loops);
     add_path(g.get(), n);
     return g;
@@ -128,12 +128,12 @@ path_graph(
 
 std::unique_ptr<Network>
 cycle_graph(
-    size_t n,
+    std::size_t n,
     EdgeDir dir
 )
 {
     std::string name = "C_" + std::to_string(n);
-    bool allows_loops = false;
+    LoopMode allows_loops = LoopMode::DISALLOWED;
     auto g = std::make_unique<Network>(name, dir, allows_loops);
     add_cycle(g.get(), n);
     return g;
@@ -142,12 +142,12 @@ cycle_graph(
 
 std::unique_ptr<Network>
 wheel_graph(
-    size_t n
+    std::size_t n
 )
 {
     std::string name = "W_" + std::to_string(n);
     EdgeDir dir = EdgeDir::UNDIRECTED;
-    bool allows_loops = false;
+    LoopMode allows_loops = LoopMode::DISALLOWED;
     auto g = std::make_unique<Network>(name, dir, allows_loops);
     add_wheel(g.get(), n);
     return g;
