@@ -14,19 +14,19 @@ class
 
   private:
 
-    size_t n_;
+    std::size_t n_;
     bool val_;
 
   public:
 
     UniformDiscretization(
-        size_t n,
+        std::size_t n,
         bool val
     ) : n_(n), val_(val)
     {}
 
     UniformDiscretization(
-        size_t n
+        std::size_t n
     ) : n_(n), val_(true)
     {}
 
