@@ -12,7 +12,7 @@ std::unique_ptr<C>
 vslice(
     const std::string& cube_name,
     C* cube,
-    const std::vector<std::vector<size_t>>& indexes
+    const std::vector<std::vector<std::size_t>>& indexes
 );
 
 // utility functions
@@ -21,7 +21,7 @@ template <typename C>
 std::vector<std::vector<std::string>>
                                    filter_members(
                                        const C* cube,
-                                       const std::vector<std::vector<size_t>>& indexes
+                                       const std::vector<std::vector<std::size_t>>& indexes
                                    );
 
 }
